# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SMOOTH_ESTIMATE_METADATA = Metadata(
    id="9874feac324ba1b8cf757cbd7cf867830eef7cee.boutiques",
    name="smooth_estimate",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SmoothEstimateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `smooth_estimate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    res_volume: OutputPathType | None
    """Residual fit image"""
    zstat_volume: OutputPathType | None
    """Zstat image"""


def smooth_estimate(
    mask_file: InputPathType,
    dof: int | None = None,
    residual_fit_file: InputPathType | None = None,
    zstat_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> SmoothEstimateOutputs:
    """
    Estimates the smoothness of an image.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        mask_file: Brain mask volume.
        dof: Number of degrees of freedom.
        residual_fit_file: Residual-fit image file.
        zstat_file: Zstat image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SmoothEstimateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SMOOTH_ESTIMATE_METADATA)
    cargs = []
    cargs.append("smoothest")
    if dof is not None:
        cargs.append("--dof=" + str(dof))
    cargs.append("--mask=" + execution.input_file(mask_file))
    if residual_fit_file is not None:
        cargs.append("--res=" + execution.input_file(residual_fit_file))
    if zstat_file is not None:
        cargs.append("--zstat=" + execution.input_file(zstat_file))
    ret = SmoothEstimateOutputs(
        root=execution.output_file("."),
        res_volume=execution.output_file(pathlib.Path(residual_fit_file).name) if (residual_fit_file is not None) else None,
        zstat_volume=execution.output_file(pathlib.Path(zstat_file).name) if (zstat_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SMOOTH_ESTIMATE_METADATA",
    "SmoothEstimateOutputs",
    "smooth_estimate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_NMT_METADATA = Metadata(
    id="633471699f3ec0b5e1dba7c99d8f03be3987c8b8.boutiques",
    name="@Install_NMT",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallNmtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_nmt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_nmt(
    install_dir: str | None = None,
    version: str | None = None,
    variant: str | None = None,
    overwrite: bool = False,
    wget: bool = False,
    curl: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VInstallNmtOutputs:
    """
    Installs the NIMH Macaque Template (NMT) with the accompanying Cortical
    Hierarchy Atlas of the Rhesus Macaque (CHARM).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_NMT.html
    
    Args:
        install_dir: The install location for the NMT.
        version: The version of the NMT you wish to install (valid options:\
            2.1, 2.0, 1.3, 1.2).
        variant: The NMT v2 has both a symmetric and asymmetric variant.\
            Specify as either 'sym' or 'asym'. Valid for NMT v2 only.
        overwrite: Allows the script to remove a pre-existing NMT directory.
        wget: Use wget to download archive. Script chooses by default with\
            preference for curl.
        curl: Use curl to download archive. Script chooses by default with\
            preference for curl.
        help_: Displays the help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallNmtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_NMT_METADATA)
    cargs = []
    cargs.append("Install_NMT")
    if install_dir is not None:
        cargs.append(install_dir)
    if version is not None:
        cargs.extend([
            "-nmt_ver",
            version
        ])
    if variant is not None:
        cargs.extend([
            "-sym",
            variant
        ])
    if overwrite:
        cargs.append("-overwrite")
    if wget:
        cargs.append("-wget")
    if curl:
        cargs.append("-curl")
    if help_:
        cargs.append("-help")
    ret = VInstallNmtOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallNmtOutputs",
    "V__INSTALL_NMT_METADATA",
    "v__install_nmt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PNGAPPEND_METADATA = Metadata(
    id="4411b6d37915e58f561527f34913fc3b997e325e.boutiques",
    name="pngappend",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PngappendOutputs(typing.NamedTuple):
    """
    Output object returned when calling `pngappend(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def pngappend(
    input_files_and_options: list[str],
    output_file: InputPathType,
    runner: Runner | None = None,
) -> PngappendOutputs:
    """
    Append PNG files horizontally and/or vertically into a new PNG (or GIF) file.
    
    Author: Unknown
    
    Args:
        input_files_and_options: List of input files and options for appending\
            (e.g., file1.png +3 file2.png -2 file3.png).
        output_file: Output file (e.g., output.png or output.gif).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PngappendOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PNGAPPEND_METADATA)
    cargs = []
    cargs.append("pngappend")
    cargs.extend(input_files_and_options)
    cargs.append(execution.input_file(output_file))
    ret = PngappendOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PNGAPPEND_METADATA",
    "PngappendOutputs",
    "pngappend",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RBA_METADATA = Metadata(
    id="2e2d3c0609d2dd89f839da84b1f13546e7903d2b.boutiques",
    name="RBA",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RbaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rba(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_txt: OutputPathType
    """Main output text file with inference information for effects of
    interest."""
    output_rdata: OutputPathType
    """Saved R data in binary format for post hoc processing."""


def rba(
    prefix: str,
    data_table: InputPathType,
    chains: float | None = None,
    iterations: float | None = None,
    model: str | None = None,
    eoi: str | None = None,
    wcp: float | None = None,
    tstat: str | None = None,
    stdz: str | None = None,
    c_vars: str | None = None,
    q_vars: str | None = None,
    dist_roi: str | None = None,
    dist_subj: str | None = None,
    dist_y: str | None = None,
    ridge_plot: str | None = None,
    roi: str | None = None,
    subj: str | None = None,
    scale: float | None = None,
    se: str | None = None,
    pdp: str | None = None,
    mean: str | None = None,
    sigma: str | None = None,
    debug: bool = False,
    verbose: float | None = None,
    md: bool = False,
    r2z: bool = False,
    runner: Runner | None = None,
) -> RbaOutputs:
    """
    Region-Based Analysis Program through Bayesian Multilevel Modeling.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/RBA.html
    
    Args:
        prefix: Prefix for output file names.
        data_table: Data table in pure text format.
        chains: Specify the number of Markov chains.
        iterations: Specify the number of iterations per Markov chain.
        model: Specify the model formula.
        eoi: Identify effects of interest in the output.
        wcp: Invoke within-chain parallelization.
        tstat: Specify the column name that lists the t-statistic values.
        stdz: Identify quantitative variables (or covariates) to be\
            standardized.
        c_vars: Identify categorical (qualitative) variables (or factors).
        q_vars: Identify quantitative variables (or covariates).
        dist_roi: Specify the distribution for the ROIs.
        dist_subj: Specify the distribution for the subjects.
        dist_y: Specify the distribution for the response variable.
        ridge_plot: Plot the posterior distributions stacked together.
        roi: Specify the column name that is designated as the region variable.
        subj: Specify the column name that is designated as the measuring unit\
            variable (usually subject).
        scale: Specify a multiplier for the Y values.
        se: This option indicates that standard error for the response variable\
            is available as input.
        pdp: Specify the layout of posterior distribution plot.
        mean: Specify the formulation for the mean of the likelihood (sampling\
            distribution).
        sigma: Specify the formulation for the standard deviation (sigma) of\
            the likelihood (sampling distribution).
        debug: This option will enable R to save the parameters in a file for\
            debugging.
        verbose: Specify verbose level.
        md: This option indicates that there are missing data in the input.
        r2z: Perform Fisher transformation on the response variable if it is a\
            correlation coefficient.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RbaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RBA_METADATA)
    cargs = []
    cargs.append("RBA")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([
        "-dataTable",
        execution.input_file(data_table)
    ])
    if chains is not None:
        cargs.extend([
            "-chains",
            str(chains)
        ])
    if iterations is not None:
        cargs.extend([
            "-iterations",
            str(iterations)
        ])
    if model is not None:
        cargs.extend([
            "-model",
            model
        ])
    if eoi is not None:
        cargs.extend([
            "-EOI",
            eoi
        ])
    if wcp is not None:
        cargs.extend([
            "-WCP",
            str(wcp)
        ])
    if tstat is not None:
        cargs.extend([
            "-tstat",
            tstat
        ])
    if stdz is not None:
        cargs.extend([
            "-stdz",
            stdz
        ])
    if c_vars is not None:
        cargs.extend([
            "-cVars",
            c_vars
        ])
    if q_vars is not None:
        cargs.extend([
            "-qVars",
            q_vars
        ])
    if dist_roi is not None:
        cargs.extend([
            "-distROI",
            dist_roi
        ])
    if dist_subj is not None:
        cargs.extend([
            "-distSubj",
            dist_subj
        ])
    if dist_y is not None:
        cargs.extend([
            "-distY",
            dist_y
        ])
    if ridge_plot is not None:
        cargs.extend([
            "-ridgePlot",
            ridge_plot
        ])
    if roi is not None:
        cargs.extend([
            "-ROI",
            roi
        ])
    if subj is not None:
        cargs.extend([
            "-Subj",
            subj
        ])
    if scale is not None:
        cargs.extend([
            "-scale",
            str(scale)
        ])
    if se is not None:
        cargs.extend([
            "-se",
            se
        ])
    if pdp is not None:
        cargs.extend([
            "-PDP",
            pdp
        ])
    if mean is not None:
        cargs.extend([
            "-mean",
            mean
        ])
    if sigma is not None:
        cargs.extend([
            "-sigma",
            sigma
        ])
    if debug:
        cargs.append("-dbgArgs")
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    if md:
        cargs.append("-MD")
    if r2z:
        cargs.append("-r2z")
    ret = RbaOutputs(
        root=execution.output_file("."),
        output_txt=execution.output_file(prefix + ".txt"),
        output_rdata=execution.output_file(prefix + ".RData"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RBA_METADATA",
    "RbaOutputs",
    "rba",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METADATA_STRING_REPLACE_METADATA = Metadata(
    id="1e9a9700045983874866c60a6a64cc275614b03c.boutiques",
    name="metadata-string-replace",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetadataStringReplaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metadata_string_replace(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metadata_string_replace(
    input_file: str,
    find_string: str,
    replace_string: str,
    output_file: str,
    opt_case_insensitive: bool = False,
    runner: Runner | None = None,
) -> MetadataStringReplaceOutputs:
    """
    Replace a string in all metadata of a file.
    
    Replaces all occurrences of <find-string> in the metadata and map names of
    <input-file> with <replace-string>.
    
    Author: Washington University School of Medicin
    
    Args:
        input_file: the file to replace metadata in.
        find_string: the string to find.
        replace_string: the string to replace <find-string> with.
        output_file: output - the name to save the modified file as.
        opt_case_insensitive: match with case variation also.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetadataStringReplaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METADATA_STRING_REPLACE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metadata-string-replace")
    cargs.append(input_file)
    cargs.append(find_string)
    cargs.append(replace_string)
    cargs.append(output_file)
    if opt_case_insensitive:
        cargs.append("-case-insensitive")
    ret = MetadataStringReplaceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METADATA_STRING_REPLACE_METADATA",
    "MetadataStringReplaceOutputs",
    "metadata_string_replace",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__RADIAL_CORRELATE_METADATA = Metadata(
    id="b1a552cc3d34915cce72bfbd9edfd04ef85c61b5.boutiques",
    name="@radial_correlate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRadialCorrelateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__radial_correlate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corr_volumes: OutputPathType
    """Directory containing correlation volumes"""


def v__radial_correlate(
    input_files: list[InputPathType],
    runner: Runner | None = None,
) -> VRadialCorrelateOutputs:
    """
    Check datasets for correlation artifacts.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@radial_correlate.html
    
    Args:
        input_files: A list of EPI datasets.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRadialCorrelateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__RADIAL_CORRELATE_METADATA)
    cargs = []
    cargs.append("@radial_correlate")
    cargs.extend([execution.input_file(f) for f in input_files])
    cargs.append("[OPTIONS]")
    ret = VRadialCorrelateOutputs(
        root=execution.output_file("."),
        corr_volumes=execution.output_file("[RESULTS_DIR]/correlation_volumes"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRadialCorrelateOutputs",
    "V__RADIAL_CORRELATE_METADATA",
    "v__radial_correlate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FOCI_GET_PROJECTION_VERTEX_METADATA = Metadata(
    id="5fcf94c378c9d18a1d8f02757543cb80d6f34ebd.boutiques",
    name="foci-get-projection-vertex",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class FociGetProjectionVertexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `foci_get_projection_vertex(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def foci_get_projection_vertex(
    foci: InputPathType,
    surface: InputPathType,
    metric_out: str,
    opt_name_name: str | None = None,
    runner: Runner | None = None,
) -> FociGetProjectionVertexOutputs:
    """
    Get projection vertex for foci.
    
    For each focus, a column is created in <metric-out>, and the vertex with the
    most influence on its projection is assigned a value of 1 in that column,
    with all other vertices 0. If -name is used, only one focus will be used.
    
    Author: Washington University School of Medicin
    
    Args:
        foci: the foci file.
        surface: the surface related to the foci file.
        metric_out: the output metric file.
        opt_name_name: select a focus by name: the name of the focus.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociGetProjectionVertexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_GET_PROJECTION_VERTEX_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-get-projection-vertex")
    cargs.append(execution.input_file(foci))
    cargs.append(execution.input_file(surface))
    cargs.append(metric_out)
    if opt_name_name is not None:
        cargs.extend([
            "-name",
            opt_name_name
        ])
    ret = FociGetProjectionVertexOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FOCI_GET_PROJECTION_VERTEX_METADATA",
    "FociGetProjectionVertexOutputs",
    "foci_get_projection_vertex",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_RES_METADATA = Metadata(
    id="ab3b2f28632d6ed50f1a051c81d4bb9f9530aea0.boutiques",
    name="@GetAfniRes",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniResOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_res(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__get_afni_res(
    input_dataset: InputPathType,
    output_type: typing.Literal["-min", "-max", "-mean"] | None = None,
    runner: Runner | None = None,
) -> VGetAfniResOutputs:
    """
    Tool to return the voxel resolution of a dataset.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@GetAfniRes.html
    
    Args:
        input_dataset: Input dataset.
        output_type: Output type specifying whether to return the minimum,\
            maximum, or mean resolution.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniResOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_RES_METADATA)
    cargs = []
    cargs.append("@GetAfniRes")
    if output_type is not None:
        cargs.append(output_type)
    cargs.append(execution.input_file(input_dataset))
    ret = VGetAfniResOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniResOutputs",
    "V__GET_AFNI_RES_METADATA",
    "v__get_afni_res",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MBA_METADATA = Metadata(
    id="759d552c8331c6f9674ba94b1244b4b902aa52b4.boutiques",
    name="MBA",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class MbaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mba(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_txt: OutputPathType
    """Main output text file storing inference information"""
    output_rdata: OutputPathType
    """R data file for post hoc processing and plotting"""
    matrix_plot: OutputPathType
    """Matrix plot visualization of analysis"""


def mba(
    prefix: str,
    data_table: InputPathType,
    chains: int | None = None,
    iterations: int | None = None,
    model: str | None = None,
    eoi: str | None = None,
    cvars: str | None = None,
    qvars: str | None = None,
    qcvar: str | None = None,
    stdz: str | None = None,
    wcp: int | None = None,
    disty: str | None = None,
    se: str | None = None,
    dbg_args: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MbaOutputs:
    """
    Matrix-Based Analysis Program through Bayesian Multilevel Modeling.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/MBA.html
    
    Args:
        prefix: Prefix for output file names.
        data_table: Specify the data structure in a table of long format.
        chains: Specify the number of Markov chains.
        iterations: Specify the number of iterations per Markov chain.
        model: Specify the effects associated with explanatory variables.
        eoi: Identify effects of interest in the output.
        cvars: Identify categorical (qualitative) variables.
        qvars: Identify quantitative variables (or covariates).
        qcvar: Identify comparisons of interest between quantitative variables.
        stdz: Identify quantitative variables (or covariates) to be\
            standardized.
        wcp: Invoke within-chain parallelization to speed up runtime.
        disty: Specify the distribution for the response variable.
        se: Specify the column name that designates the standard error for the\
            response variable.
        dbg_args: Enable R to save the parameters in a file called\
            .MBA.dbg.AFNI.args for debugging purposes.
        help_: Show help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MbaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MBA_METADATA)
    cargs = []
    cargs.append("MBA")
    cargs.append(prefix)
    if chains is not None:
        cargs.extend([
            "-chains",
            str(chains)
        ])
    if iterations is not None:
        cargs.extend([
            "-iterations",
            str(iterations)
        ])
    if model is not None:
        cargs.extend([
            "-model",
            model
        ])
    if eoi is not None:
        cargs.extend([
            "-EOI",
            eoi
        ])
    cargs.extend([
        "-dataTable",
        execution.input_file(data_table)
    ])
    if cvars is not None:
        cargs.extend([
            "-cVars",
            cvars
        ])
    if qvars is not None:
        cargs.extend([
            "-qVars",
            qvars
        ])
    if qcvar is not None:
        cargs.extend([
            "-qContr",
            qcvar
        ])
    if stdz is not None:
        cargs.extend([
            "-stdz",
            stdz
        ])
    if wcp is not None:
        cargs.extend([
            "-WCP",
            str(wcp)
        ])
    if disty is not None:
        cargs.extend([
            "-distY",
            disty
        ])
    if se is not None:
        cargs.extend([
            "-se",
            se
        ])
    cargs.append("[RPREFIX]")
    if dbg_args:
        cargs.append("-dbgArgs")
    if help_:
        cargs.append("-help")
    ret = MbaOutputs(
        root=execution.output_file("."),
        output_txt=execution.output_file(prefix + ".txt"),
        output_rdata=execution.output_file(prefix + ".RData"),
        matrix_plot=execution.output_file(prefix + "_matrixplot.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MBA_METADATA",
    "MbaOutputs",
    "mba",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

APPLYXFM4_D_METADATA = Metadata(
    id="589ce1a495f4b6b5b1c9c49ad166dfe4742dc738.boutiques",
    name="applyxfm4D",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Applyxfm4DOutputs(typing.NamedTuple):
    """
    Output object returned when calling `applyxfm4_d(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Transformed 4D volume output"""


def applyxfm4_d(
    input_volume: InputPathType,
    ref_volume: InputPathType,
    output_volume: str,
    transformation_matrix: str,
    runner: Runner | None = None,
) -> Applyxfm4DOutputs:
    """
    Applies 4D transformation matrices to 4D volumes.
    
    Author: Unknown
    
    Args:
        input_volume: Input 4D volume (e.g. img.nii.gz).
        ref_volume: Reference volume (e.g. ref.nii.gz).
        output_volume: Output volume after applying transformation (e.g.\
            output.nii.gz).
        transformation_matrix: Transformation matrix file or directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Applyxfm4DOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(APPLYXFM4_D_METADATA)
    cargs = []
    cargs.append("applyxfm4D")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(ref_volume))
    cargs.append(output_volume)
    cargs.append(transformation_matrix)
    ret = Applyxfm4DOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "APPLYXFM4_D_METADATA",
    "Applyxfm4DOutputs",
    "applyxfm4_d",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_SEPARATE_METADATA = Metadata(
    id="194ccc1cf5962c80d53c1f06517b2bfef63ef3d9.boutiques",
    name="cifti-separate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiSeparateVolumeAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiSeparateVolumeAll | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""
    roi_out: OutputPathType
    """the roi output volume"""
    label_out: OutputPathType
    """the label output volume"""


@dataclasses.dataclass
class CiftiSeparateVolumeAll:
    """
    separate all volume structures into a volume file.
    """
    volume_out: str
    """the output volume"""
    roi_out: str
    """the roi output volume"""
    label_out: str
    """the label output volume"""
    opt_roi: bool = False
    """also output the roi of which voxels have data"""
    opt_label: bool = False
    """output a volume label file indicating the location of structures"""
    opt_crop: bool = False
    """crop volume to the size of the data rather than using the original volume
    size"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-all")
        cargs.append(self.volume_out)
        if self.opt_roi:
            cargs.append("-roi")
        cargs.append(self.roi_out)
        if self.opt_label:
            cargs.append("-label")
        cargs.append(self.label_out)
        if self.opt_crop:
            cargs.append("-crop")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> CiftiSeparateVolumeAllOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `CiftiSeparateVolumeAllOutputs`).
        """
        ret = CiftiSeparateVolumeAllOutputs(
            root=execution.output_file("."),
            volume_out=execution.output_file(self.volume_out),
            roi_out=execution.output_file(self.roi_out),
            label_out=execution.output_file(self.label_out),
        )
        return ret


class CiftiSeparateLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateLabel] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""
    roi_out: OutputPathType
    """the roi output metric"""


@dataclasses.dataclass
class CiftiSeparateLabel:
    """
    separate a surface model into a surface label file.
    """
    structure: str
    """the structure to output"""
    label_out: str
    """the output label file"""
    roi_out: str
    """the roi output metric"""
    opt_roi: bool = False
    """also output the roi of which vertices have data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-label")
        cargs.append(self.structure)
        cargs.append(self.label_out)
        if self.opt_roi:
            cargs.append("-roi")
        cargs.append(self.roi_out)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> CiftiSeparateLabelOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `CiftiSeparateLabelOutputs`).
        """
        ret = CiftiSeparateLabelOutputs(
            root=execution.output_file("."),
            label_out=execution.output_file(self.label_out),
            roi_out=execution.output_file(self.roi_out),
        )
        return ret


class CiftiSeparateMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateMetric] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""
    roi_out: OutputPathType
    """the roi output metric"""


@dataclasses.dataclass
class CiftiSeparateMetric:
    """
    separate a surface model into a metric file.
    """
    structure: str
    """the structure to output"""
    metric_out: str
    """the output metric"""
    roi_out: str
    """the roi output metric"""
    opt_roi: bool = False
    """also output the roi of which vertices have data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-metric")
        cargs.append(self.structure)
        cargs.append(self.metric_out)
        if self.opt_roi:
            cargs.append("-roi")
        cargs.append(self.roi_out)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> CiftiSeparateMetricOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `CiftiSeparateMetricOutputs`).
        """
        ret = CiftiSeparateMetricOutputs(
            root=execution.output_file("."),
            metric_out=execution.output_file(self.metric_out),
            roi_out=execution.output_file(self.roi_out),
        )
        return ret


class CiftiSeparateVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[CiftiSeparateVolume] | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""
    roi_out: OutputPathType
    """the roi output volume"""


@dataclasses.dataclass
class CiftiSeparateVolume:
    """
    separate a volume structure into a volume file.
    """
    structure: str
    """the structure to output"""
    volume_out: str
    """the output volume"""
    roi_out: str
    """the roi output volume"""
    opt_roi: bool = False
    """also output the roi of which voxels have data"""
    opt_crop: bool = False
    """crop volume to the size of the component rather than using the original
    volume size"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume")
        cargs.append(self.structure)
        cargs.append(self.volume_out)
        if self.opt_roi:
            cargs.append("-roi")
        cargs.append(self.roi_out)
        if self.opt_crop:
            cargs.append("-crop")
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> CiftiSeparateVolumeOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `CiftiSeparateVolumeOutputs`).
        """
        ret = CiftiSeparateVolumeOutputs(
            root=execution.output_file("."),
            volume_out=execution.output_file(self.volume_out),
            roi_out=execution.output_file(self.roi_out),
        )
        return ret


class CiftiSeparateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_separate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_all: CiftiSeparateVolumeAllOutputs | None
    """Outputs from `CiftiSeparateVolumeAll`."""
    label: typing.List[CiftiSeparateLabelOutputs] | None
    """Outputs from `CiftiSeparateLabel`.This is a list of outputs with the same
    length and order as the inputs."""
    metric: typing.List[CiftiSeparateMetricOutputs] | None
    """Outputs from `CiftiSeparateMetric`.This is a list of outputs with the
    same length and order as the inputs."""
    volume: typing.List[CiftiSeparateVolumeOutputs] | None
    """Outputs from `CiftiSeparateVolume`.This is a list of outputs with the
    same length and order as the inputs."""


def cifti_separate(
    cifti_in: InputPathType,
    direction: str,
    volume_all: CiftiSeparateVolumeAll | None = None,
    label: list[CiftiSeparateLabel] | None = None,
    metric: list[CiftiSeparateMetric] | None = None,
    volume: list[CiftiSeparateVolume] | None = None,
    runner: Runner | None = None,
) -> CiftiSeparateOutputs:
    """
    Write a cifti structure as metric, label or volume.
    
    For dtseries, dscalar, and dlabel, use COLUMN for <direction>, and if you
    have a symmetric dconn, COLUMN is more efficient.
    
    You must specify at least one of -metric, -volume-all, -volume, or -label
    for this command to do anything. Output volumes will spatially line up with
    their original positions, whether or not they are cropped. Volume files
    produced by separating a dlabel file, or from the -label suboption of
    -volume-all, will be label volumes, see -volume-help.
    
    For each <structure> argument, use one of the following strings:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the cifti to separate a component of.
        direction: which direction to separate into components, ROW or COLUMN.
        volume_all: separate all volume structures into a volume file.
        label: separate a surface model into a surface label file.
        metric: separate a surface model into a metric file.
        volume: separate a volume structure into a volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSeparateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_SEPARATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-separate")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(direction)
    if volume_all is not None:
        cargs.extend(volume_all.run(execution))
    if label is not None:
        cargs.extend([a for c in [s.run(execution) for s in label] for a in c])
    if metric is not None:
        cargs.extend([a for c in [s.run(execution) for s in metric] for a in c])
    if volume is not None:
        cargs.extend([a for c in [s.run(execution) for s in volume] for a in c])
    ret = CiftiSeparateOutputs(
        root=execution.output_file("."),
        volume_all=volume_all.outputs(execution) if volume_all else None,
        label=[i.outputs(execution) for i in label] if label else None,
        metric=[i.outputs(execution) for i in metric] if metric else None,
        volume=[i.outputs(execution) for i in volume] if volume else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_SEPARATE_METADATA",
    "CiftiSeparateLabel",
    "CiftiSeparateLabelOutputs",
    "CiftiSeparateMetric",
    "CiftiSeparateMetricOutputs",
    "CiftiSeparateOutputs",
    "CiftiSeparateVolume",
    "CiftiSeparateVolumeAll",
    "CiftiSeparateVolumeAllOutputs",
    "CiftiSeparateVolumeOutputs",
    "cifti_separate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONNECTEDCOMP_METADATA = Metadata(
    id="4d630a5c9dd96234ed4b80fc339005c5f4b78137.boutiques",
    name="connectedcomp",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ConnectedcompOutputs(typing.NamedTuple):
    """
    Output object returned when calling `connectedcomp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType | None
    """The output image volume"""


def connectedcomp(
    in_volume: InputPathType,
    output_volume: InputPathType | None = None,
    num_connect: int | None = None,
    runner: Runner | None = None,
) -> ConnectedcompOutputs:
    """
    Connected component analysis tool.
    
    Author: Unknown
    
    Args:
        in_volume: Input image volume.
        output_volume: Output image volume.
        num_connect: Number of connected components.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConnectedcompOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONNECTEDCOMP_METADATA)
    cargs = []
    cargs.append("connectedcomp")
    cargs.append(execution.input_file(in_volume))
    if output_volume is not None:
        cargs.append(execution.input_file(output_volume))
    if num_connect is not None:
        cargs.append(str(num_connect))
    ret = ConnectedcompOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(pathlib.Path(output_volume).name) if (output_volume is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONNECTEDCOMP_METADATA",
    "ConnectedcompOutputs",
    "connectedcomp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TRR_METADATA = Metadata(
    id="fa558271c9da9bb419e2a1146021b4c1c11a0615.boutiques",
    name="TRR",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class TrrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `trr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file_txt: OutputPathType
    """Main output file containing inference information for effects of
    interest"""
    output_file_pdf: OutputPathType
    """Density plot of the TRR distribution"""
    output_file_rdata: OutputPathType
    """Saved R data in binary format for post hoc processing"""


def trr(
    prefix: str,
    response_var: str,
    subject_var: str,
    data_table: InputPathType,
    chains: float | None = None,
    iterations: float | None = None,
    repetition_var: str | None = None,
    condition_var: str | None = None,
    categorical_vars: str | None = None,
    quantitative_vars: str | None = None,
    response_dist: str | None = None,
    model: str | None = None,
    plot_size: list[float] | None = None,
    standard_error: str | None = None,
    t_stat: str | None = None,
    within_chain_parallelization: float | None = None,
    debug: bool = False,
    verbose: float | None = None,
    runner: Runner | None = None,
) -> TrrOutputs:
    """
    Test-Retest Reliability Program through Bayesian Multilevel Modeling.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/TRR.html
    
    Args:
        prefix: Prefix for output file names.
        response_var: Specify the column name for the response variable.
        subject_var: Specify the column name for the subject variable.
        data_table: Specify the path to the data table in pure text format.
        chains: Specify the number of Markov chains.
        iterations: Specify the number of iterations per Markov chain.
        repetition_var: Specify the column name for the repetition variable.
        condition_var: Specify the column name for the condition variable.
        categorical_vars: Identify categorical (qualitative) variables.
        quantitative_vars: Identify quantitative (covariate) variables.
        response_dist: Specify the distribution for the response variable\
            (e.g., 'gaussian', 'student', 'exgaussian').
        model: Specify the effects associated with explanatory variables.
        plot_size: Specify the layout of posterior distribution plot (PDP) with\
            width and height in inches.
        standard_error: Include standard error for the response variable as\
            input.
        t_stat: Specify the column name for the t-statistic values.
        within_chain_parallelization: Invoke within-chain parallelization;\
            specify number of threads per chain.
        debug: Enable R to save the parameters for debugging.
        verbose: Specify verbose level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TrrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TRR_METADATA)
    cargs = []
    cargs.append("TRR")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if chains is not None:
        cargs.extend([
            "-chains",
            str(chains)
        ])
    if iterations is not None:
        cargs.extend([
            "-iterations",
            str(iterations)
        ])
    cargs.extend([
        "-Y",
        response_var
    ])
    cargs.extend([
        "-subject",
        subject_var
    ])
    if repetition_var is not None:
        cargs.extend([
            "-repetition",
            repetition_var
        ])
    if condition_var is not None:
        cargs.extend([
            "-condition",
            condition_var
        ])
    cargs.extend([
        "-dataTable",
        execution.input_file(data_table)
    ])
    if categorical_vars is not None:
        cargs.extend([
            "-cVars",
            categorical_vars
        ])
    if quantitative_vars is not None:
        cargs.extend([
            "-qVars",
            quantitative_vars
        ])
    if response_dist is not None:
        cargs.extend([
            "-distY",
            response_dist
        ])
    if model is not None:
        cargs.extend([
            "-model",
            model
        ])
    if plot_size is not None:
        cargs.extend([
            "-PDP",
            *map(str, plot_size)
        ])
    if standard_error is not None:
        cargs.extend([
            "-se",
            standard_error
        ])
    if t_stat is not None:
        cargs.extend([
            "-tstat",
            t_stat
        ])
    if within_chain_parallelization is not None:
        cargs.extend([
            "-WCP",
            str(within_chain_parallelization)
        ])
    if debug:
        cargs.append("-dbgArgs")
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    ret = TrrOutputs(
        root=execution.output_file("."),
        output_file_txt=execution.output_file(prefix + ".txt"),
        output_file_pdf=execution.output_file(prefix + ".pdf"),
        output_file_rdata=execution.output_file(prefix + ".RData"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TRR_METADATA",
    "TrrOutputs",
    "trr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOCAL_HISTOG_METADATA = Metadata(
    id="15de7373d7efff509716e5d6e31df5725696bf4a.boutiques",
    name="3dLocalHistog",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLocalHistogOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_local_histog(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_head: OutputPathType
    """The output dataset with the specified prefix"""
    output_dataset_brik: OutputPathType
    """The output dataset with the specified prefix"""
    histogram_file: OutputPathType | None
    """The overall histogram saved into the specified file"""


def v_3d_local_histog(
    prefix: str,
    input_datasets: list[InputPathType],
    nbhd_option: str | None = None,
    hsave: str | None = None,
    lab_file: InputPathType | None = None,
    exclude: list[str] | None = None,
    mincount: float | None = None,
    runner: Runner | None = None,
) -> V3dLocalHistogOutputs:
    """
    This program computes a local histogram at each voxel in the input datasets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dLocalHistog.html
    
    Args:
        prefix: Use string 'ppp' as the prefix for the output dataset.
        input_datasets: Input dataset(s) for the 3dLocalHistog tool.
        nbhd_option: Defines the region around each voxel to be used for the\
            statistics calculation. Available formats: 'SPHERE(r)', 'RECT(a,b,c)',\
            'RHDD(a)', 'TOHD(a)'.
        hsave: Save the overall histogram into file 'sss'. This file will have\
            2 columns: value and count.
        lab_file: Use file 'LL' as a label file.
        exclude: Exclude values from 'a' to 'b' from the counting. This option\
            can be used more than once.
        mincount: Exclude values which appear in the overall histogram fewer\
            than 'mm' times.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLocalHistogOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOCAL_HISTOG_METADATA)
    cargs = []
    cargs.append("3dLocalHistog")
    if nbhd_option is not None:
        cargs.extend([
            "-nbhd",
            nbhd_option
        ])
    cargs.append("-prefix")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if hsave is not None:
        cargs.extend([
            "-hsave",
            hsave
        ])
    if lab_file is not None:
        cargs.extend([
            "-lab_file",
            execution.input_file(lab_file)
        ])
    if exclude is not None:
        cargs.extend([
            "-exclude",
            *exclude
        ])
    if mincount is not None:
        cargs.extend([
            "-mincount",
            str(mincount)
        ])
    cargs.extend([execution.input_file(f) for f in input_datasets])
    ret = V3dLocalHistogOutputs(
        root=execution.output_file("."),
        output_dataset_head=execution.output_file(prefix + "+orig.HEAD"),
        output_dataset_brik=execution.output_file(prefix + "+orig.BRIK"),
        histogram_file=execution.output_file(hsave) if (hsave is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLocalHistogOutputs",
    "V_3D_LOCAL_HISTOG_METADATA",
    "v_3d_local_histog",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_VERTEX_AREAS_METADATA = Metadata(
    id="f99539e6c03e9d952d920096d6ea72347bfef0d1.boutiques",
    name="surface-vertex-areas",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceVertexAreasOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_vertex_areas(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric: OutputPathType
    """the output metric"""


def surface_vertex_areas(
    surface: InputPathType,
    metric: str,
    runner: Runner | None = None,
) -> SurfaceVertexAreasOutputs:
    """
    Measure surface area each vertex is responsible for.
    
    Each vertex gets one third of the area of each triangle it is a part of.
    Units are mm^2.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to measure.
        metric: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceVertexAreasOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_VERTEX_AREAS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-vertex-areas")
    cargs.append(execution.input_file(surface))
    cargs.append(metric)
    ret = SurfaceVertexAreasOutputs(
        root=execution.output_file("."),
        metric=execution.output_file(metric),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_VERTEX_AREAS_METADATA",
    "SurfaceVertexAreasOutputs",
    "surface_vertex_areas",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_JACOBIAN_METADATA = Metadata(
    id="e0b54148f03bbce672bfc24966b15e2f4a38745b.boutiques",
    name="reg_jacobian",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegJacobianOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_jacobian(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jacobian_file: OutputPathType
    """File containing the Jacobian determinant map"""
    output_jacobian_matrix_file: OutputPathType
    """File containing the Jacobian matrix map"""
    output_log_jacobian_file: OutputPathType
    """File containing the log of the Jacobian determinant map"""


def reg_jacobian(
    reference_image: InputPathType,
    runner: Runner | None = None,
) -> RegJacobianOutputs:
    """
    Tool to compute the Jacobian determinant map from a deformation field or control
    point lattice.
    
    Author: Marc Modat
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegJacobianOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_JACOBIAN_METADATA)
    cargs = []
    cargs.append("reg_jacobian")
    cargs.append("-ref")
    cargs.extend([
        "-target",
        execution.input_file(reference_image)
    ])
    cargs.append("[INPUT_TYPE]")
    cargs.append("[OUTPUT_OPTIONS]")
    cargs.append("[EXTRA_OPTIONS]")
    ret = RegJacobianOutputs(
        root=execution.output_file("."),
        output_jacobian_file=execution.output_file("[OUTPUT_JACOBIAN]"),
        output_jacobian_matrix_file=execution.output_file("[OUTPUT_JACOBIAN_MATRIX]"),
        output_log_jacobian_file=execution.output_file("[OUTPUT_LOG_JACOBIAN]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_JACOBIAN_METADATA",
    "RegJacobianOutputs",
    "reg_jacobian",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RUN_FIRST_METADATA = Metadata(
    id="f6433113c41496029bfddb8322e805b4e5730fa1.boutiques",
    name="run_first",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class RunFirstOutputs(typing.NamedTuple):
    """
    Output object returned when calling `run_first(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files generated by FIRST"""


def run_first(
    input_image: InputPathType,
    transformation_matrix: InputPathType,
    n_modes: float,
    output_basename: str,
    model_name: InputPathType,
    verbose_flag: bool = False,
    intref_model_name: str | None = None,
    load_bvars: InputPathType | None = None,
    multiple_images_flag: bool = False,
    runner: Runner | None = None,
) -> RunFirstOutputs:
    """
    A tool to run FSL's FIRST for subcortical segmentation.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FIRST
    
    Args:
        input_image: Input image file (e.g. img.nii.gz).
        transformation_matrix: Input transformation matrix file (e.g.\
            input_to_mni.mat).
        n_modes: Number of modes.
        output_basename: Output basename.
        model_name: Model name.
        verbose_flag: Verbose mode.
        intref_model_name: Reference structure for the local intensity\
            normalization.
        load_bvars: Initializes FIRST with a previous estimate of the structure.
        multiple_images_flag: Run FIRST on multiple images; provide a list of\
            images, transformation matrices, and output names.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RunFirstOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RUN_FIRST_METADATA)
    cargs = []
    cargs.append("run_first")
    cargs.append("-i")
    cargs.append(execution.input_file(input_image))
    cargs.append("-t")
    cargs.append(execution.input_file(transformation_matrix))
    cargs.append("-n")
    cargs.append(str(n_modes))
    cargs.append("-o")
    cargs.append(output_basename)
    cargs.append("-m")
    cargs.append(execution.input_file(model_name))
    if verbose_flag:
        cargs.append("-v")
    if intref_model_name is not None:
        cargs.extend([
            "-intref",
            intref_model_name
        ])
    if load_bvars is not None:
        cargs.extend([
            "-loadBvars",
            execution.input_file(load_bvars)
        ])
    if multiple_images_flag:
        cargs.append("-multipleImages")
    ret = RunFirstOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_basename + "*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RUN_FIRST_METADATA",
    "RunFirstOutputs",
    "run_first",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BETSURF_METADATA = Metadata(
    id="8c8def8d6fc4d834cdaf615cbec87b9e20bcd394.boutiques",
    name="betsurf",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class BetsurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `betsurf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType
    """Generated binary mask"""
    output_outline: OutputPathType
    """Generated surface outline"""
    output_skull: OutputPathType
    """Generated skull mask"""


def betsurf(
    runner: Runner | None = None,
) -> BetsurfOutputs:
    """
    BET Surface Finder to extract brain surfaces using T1 and T2 images.
    
    Author: FMRIB Analysis Group, Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/BET
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BetsurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BETSURF_METADATA)
    cargs = []
    cargs.append("betsurf")
    cargs.append("[OPTIONS]")
    cargs.append("<t1>")
    cargs.append("[<t2>]")
    cargs.append("<bet_mesh.vtk>")
    cargs.append("<t1_to_standard.mat>")
    cargs.append("<output>")
    ret = BetsurfOutputs(
        root=execution.output_file("."),
        output_mask=execution.output_file("[OUTPUT_PREFIX]_mask.nii.gz"),
        output_outline=execution.output_file("[OUTPUT_PREFIX]_outline.nii.gz"),
        output_skull=execution.output_file("[OUTPUT_PREFIX]_skull.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BETSURF_METADATA",
    "BetsurfOutputs",
    "betsurf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XTRACT_STATS_METADATA = Metadata(
    id="f4e5e97bb4e53d159170f50f0562556e5349aa95.boutiques",
    name="xtract_stats",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class XtractStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xtract_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    csv_output: OutputPathType
    """CSV file containing the statistics from XTRACT analysis."""


def xtract_stats(
    folder_basename: str,
    xtract_dir: str,
    xtract2diff: str,
    runner: Runner | None = None,
) -> XtractStatsOutputs:
    """
    Quantitative evaluation tool of XTRACT results in neuroimaging.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/
    
    Args:
        folder_basename: Path to microstructure folder and basename of data\
            (e.g. /home/DTI/dti_).
        xtract_dir: Path to XTRACT output folder.
        xtract2diff: EITHER XTRACT results to diffusion space transform OR\
            'native' if tracts are already in diffusion space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XtractStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XTRACT_STATS_METADATA)
    cargs = []
    cargs.append("xtract_stats")
    cargs.append("-d")
    cargs.append(folder_basename)
    cargs.append("-xtract")
    cargs.append(xtract_dir)
    cargs.append("-w")
    cargs.append(xtract2diff)
    cargs.append("[reference]")
    cargs.append("[output_file]")
    cargs.append("[structures_file]")
    cargs.append("[threshold]")
    cargs.append("[measurements]")
    cargs.append("[keep_temp_files]")
    ret = XtractStatsOutputs(
        root=execution.output_file("."),
        csv_output=execution.output_file("<output_file>"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XTRACT_STATS_METADATA",
    "XtractStatsOutputs",
    "xtract_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_SMOOTHING_METADATA = Metadata(
    id="b4300c9ee0a42249cb5d5f1c7e92863362e036ff.boutiques",
    name="cifti-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiSmoothingLeftSurface:
    """
    specify the left surface to use.
    """
    surface: InputPathType
    """the left surface file"""
    opt_left_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the left surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-left-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_left_corrected_areas_area_metric is not None:
            cargs.extend([
                "-left-corrected-areas",
                execution.input_file(self.opt_left_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiSmoothingRightSurface:
    """
    specify the right surface to use.
    """
    surface: InputPathType
    """the right surface file"""
    opt_right_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the right surface: the
    corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-right-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_right_corrected_areas_area_metric is not None:
            cargs.extend([
                "-right-corrected-areas",
                execution.input_file(self.opt_right_corrected_areas_area_metric)
            ])
        return cargs


@dataclasses.dataclass
class CiftiSmoothingCerebellumSurface:
    """
    specify the cerebellum surface to use.
    """
    surface: InputPathType
    """the cerebellum surface file"""
    opt_cerebellum_corrected_areas_area_metric: InputPathType | None = None
    """vertex areas to use instead of computing them from the cerebellum
    surface: the corrected vertex areas, as a metric"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cerebellum-surface")
        cargs.append(execution.input_file(self.surface))
        if self.opt_cerebellum_corrected_areas_area_metric is not None:
            cargs.extend([
                "-cerebellum-corrected-areas",
                execution.input_file(self.opt_cerebellum_corrected_areas_area_metric)
            ])
        return cargs


class CiftiSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_smoothing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti"""


def cifti_smoothing(
    cifti: InputPathType,
    surface_kernel: float,
    volume_kernel: float,
    direction: str,
    cifti_out: str,
    opt_fwhm: bool = False,
    left_surface: CiftiSmoothingLeftSurface | None = None,
    right_surface: CiftiSmoothingRightSurface | None = None,
    cerebellum_surface: CiftiSmoothingCerebellumSurface | None = None,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_fix_zeros_volume: bool = False,
    opt_fix_zeros_surface: bool = False,
    opt_merged_volume: bool = False,
    runner: Runner | None = None,
) -> CiftiSmoothingOutputs:
    """
    Smooth a cifti file.
    
    The input cifti file must have a brain models mapping on the chosen
    dimension, columns for .dtseries, and either for .dconn. By default, data in
    different structures is smoothed independently (i.e., "parcel constrained"
    smoothing), so volume structures that touch do not smooth across this
    boundary. Specify -merged-volume to ignore these boundaries. Surface
    smoothing uses the GEO_GAUSS_AREA smoothing method.
    
    The -*-corrected-areas options are intended for when it is unavoidable to
    smooth on group average surfaces, it is only an approximate correction for
    the reduction of structure in a group average surface. It is better to
    smooth the data on individuals before averaging, when feasible.
    
    The -fix-zeros-* options will treat values of zero as lack of data, and not
    use that value when generating the smoothed values, but will fill zeros with
    extrapolated values. The ROI should have a brain models mapping along
    columns, exactly matching the mapping of the chosen direction in the input
    file. Data outside the ROI is ignored.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti: the input cifti.
        surface_kernel: the size of the gaussian surface smoothing kernel in\
            mm, as sigma by default.
        volume_kernel: the size of the gaussian volume smoothing kernel in mm,\
            as sigma by default.
        direction: which dimension to smooth along, ROW or COLUMN.
        cifti_out: the output cifti.
        opt_fwhm: kernel sizes are FWHM, not sigma.
        left_surface: specify the left surface to use.
        right_surface: specify the right surface to use.
        cerebellum_surface: specify the cerebellum surface to use.
        opt_cifti_roi_roi_cifti: smooth only within regions of interest: the\
            regions to smooth within, as a cifti file.
        opt_fix_zeros_volume: treat values of zero in the volume as missing\
            data.
        opt_fix_zeros_surface: treat values of zero on the surface as missing\
            data.
        opt_merged_volume: smooth across subcortical structure boundaries.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_SMOOTHING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-smoothing")
    cargs.append(execution.input_file(cifti))
    cargs.append(str(surface_kernel))
    cargs.append(str(volume_kernel))
    cargs.append(direction)
    cargs.append(cifti_out)
    if opt_fwhm:
        cargs.append("-fwhm")
    if left_surface is not None:
        cargs.extend(left_surface.run(execution))
    if right_surface is not None:
        cargs.extend(right_surface.run(execution))
    if cerebellum_surface is not None:
        cargs.extend(cerebellum_surface.run(execution))
    if opt_cifti_roi_roi_cifti is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(opt_cifti_roi_roi_cifti)
        ])
    if opt_fix_zeros_volume:
        cargs.append("-fix-zeros-volume")
    if opt_fix_zeros_surface:
        cargs.append("-fix-zeros-surface")
    if opt_merged_volume:
        cargs.append("-merged-volume")
    ret = CiftiSmoothingOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_SMOOTHING_METADATA",
    "CiftiSmoothingCerebellumSurface",
    "CiftiSmoothingLeftSurface",
    "CiftiSmoothingOutputs",
    "CiftiSmoothingRightSurface",
    "cifti_smoothing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BIANCA_OVERLAP_MEASURES_METADATA = Metadata(
    id="f7c829d009f21c015e3d92bf615b7727e0971a20.boutiques",
    name="bianca_overlap_measures",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class BiancaOverlapMeasuresOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bianca_overlap_measures(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tp_auto: OutputPathType
    """True positive voxels in automatic mask"""
    tp_manual: OutputPathType
    """True positive voxels in manual mask"""
    fp_vox_tp_overlap: OutputPathType
    """False positive voxels that overlap with true positives"""
    fn_vox_tp_overlap: OutputPathType
    """False negative voxels that overlap with true positives"""
    lesmask_idx: OutputPathType
    """Indexed lesion mask"""
    manualmask_idx: OutputPathType
    """Indexed manual mask"""
    lesmask_idx_tp: OutputPathType
    """True positive indexed lesion mask"""
    manualmask_idx_tp: OutputPathType
    """True positive indexed manual mask"""


def bianca_overlap_measures(
    lesion_mask: InputPathType,
    manual_mask: InputPathType,
    output_dir: str,
    runner: Runner | None = None,
) -> BiancaOverlapMeasuresOutputs:
    """
    BIANCA overlap measures script for FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    Args:
        lesion_mask: Lesion mask image file.
        manual_mask: Manual mask image file.
        output_dir: Output directory for generated files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BiancaOverlapMeasuresOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BIANCA_OVERLAP_MEASURES_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/bianca_overlap_measures")
    cargs.append(execution.input_file(lesion_mask))
    cargs.append(execution.input_file(manual_mask))
    cargs.append(output_dir)
    ret = BiancaOverlapMeasuresOutputs(
        root=execution.output_file("."),
        tp_auto=execution.output_file("{OUTPUT_DIR}/TPauto.nii.gz"),
        tp_manual=execution.output_file("{OUTPUT_DIR}/TPmanual.nii.gz"),
        fp_vox_tp_overlap=execution.output_file("{OUTPUT_DIR}/FPvox_TP_overlap.nii.gz"),
        fn_vox_tp_overlap=execution.output_file("{OUTPUT_DIR}/FNvox_TP_overlap.nii.gz"),
        lesmask_idx=execution.output_file("{OUTPUT_DIR}/lesmask_idx.nii.gz"),
        manualmask_idx=execution.output_file("{OUTPUT_DIR}/manualmask_idx.nii.gz"),
        lesmask_idx_tp=execution.output_file("{OUTPUT_DIR}/lesmask_idx_TP.nii.gz"),
        manualmask_idx_tp=execution.output_file("{OUTPUT_DIR}/manualmask_idx_TP.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BIANCA_OVERLAP_MEASURES_METADATA",
    "BiancaOverlapMeasuresOutputs",
    "bianca_overlap_measures",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_CREATE_SCALAR_SERIES_METADATA = Metadata(
    id="731ab0e93ff863505c9e8a32b724b941eadf5abd.boutiques",
    name="cifti-create-scalar-series",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiCreateScalarSeriesSeries:
    """
    set the units and values of the series.
    """
    unit: str
    """the unit to use"""
    start: float
    """the value at the first series point"""
    step: float
    """the interval between series points"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-series")
        cargs.append(self.unit)
        cargs.append(str(self.start))
        cargs.append(str(self.step))
        return cargs


class CiftiCreateScalarSeriesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_create_scalar_series(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_create_scalar_series(
    input_: str,
    cifti_out: str,
    opt_transpose: bool = False,
    opt_name_file_file: str | None = None,
    series: CiftiCreateScalarSeriesSeries | None = None,
    runner: Runner | None = None,
) -> CiftiCreateScalarSeriesOutputs:
    """
    Import series data into cifti.
    
    Convert a text file containing series of equal length into a cifti file. The
    text file should have lines made up of numbers separated by whitespace, with
    no extra newlines between lines.
    
    The <unit> argument must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Washington University School of Medicin
    
    Args:
        input_: input file.
        cifti_out: output cifti file.
        opt_transpose: use if the rows of the text file are along the scalar\
            dimension.
        opt_name_file_file: use a text file to set names on scalar dimension:\
            text file containing names, one per line.
        series: set the units and values of the series.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateScalarSeriesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_SCALAR_SERIES_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-scalar-series")
    cargs.append(input_)
    cargs.append(cifti_out)
    if opt_transpose:
        cargs.append("-transpose")
    if opt_name_file_file is not None:
        cargs.extend([
            "-name-file",
            opt_name_file_file
        ])
    if series is not None:
        cargs.extend(series.run(execution))
    ret = CiftiCreateScalarSeriesOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_CREATE_SCALAR_SERIES_METADATA",
    "CiftiCreateScalarSeriesOutputs",
    "CiftiCreateScalarSeriesSeries",
    "cifti_create_scalar_series",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MATCH_SMOOTHING_METADATA = Metadata(
    id="20a70dcd32bab58a0d1eb3bf58ebd82cb6e4b303.boutiques",
    name="match_smoothing",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MatchSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `match_smoothing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def match_smoothing(
    example_func: InputPathType,
    func_smoothing_fwhm: float,
    example_structural: InputPathType,
    standard_space_resolution: float,
    runner: Runner | None = None,
) -> MatchSmoothingOutputs:
    """
    Computes the smoothing sigma needed to be applied to structural data to match a
    given functional data smoothing level.
    
    Args:
        example_func: Path to the example functional image file.
        func_smoothing_fwhm: Full-width at half maximum (FWHM) of the smoothing\
            kernel applied to the functional data, in millimeters.
        example_structural: Path to the example structural image file.
        standard_space_resolution: Resolution of the standard space, in\
            millimeters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MatchSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MATCH_SMOOTHING_METADATA)
    cargs = []
    cargs.append("match_smoothing")
    cargs.append(execution.input_file(example_func))
    cargs.append(str(func_smoothing_fwhm))
    cargs.append(execution.input_file(example_structural))
    cargs.append(str(standard_space_resolution))
    ret = MatchSmoothingOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MATCH_SMOOTHING_METADATA",
    "MatchSmoothingOutputs",
    "match_smoothing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ANOVA3_METADATA = Metadata(
    id="9848d10813d27662b8bd1fcf297dabbe1fca2a7a.boutiques",
    name="3dANOVA3",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAnova3Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_anova3(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_fa: OutputPathType
    """Output file for the main ANOVA result."""
    outfile_fb: OutputPathType
    """Output file for the main B ANOVA result."""
    outfile_fc: OutputPathType
    """Output file for the main C ANOVA result."""
    outfile_fab: OutputPathType
    """Output file for the interaction between A and B."""
    outfile_fac: OutputPathType
    """Output file for the interaction between A and C."""
    outfile_fbc: OutputPathType
    """Output file for the interaction between B and C."""
    outfile_fabc: OutputPathType
    """Output file for the interaction between A, B, and C."""
    outfile_amean: OutputPathType
    """Output file for the A mean results."""
    outfile_bmean: OutputPathType
    """Output file for the B mean results."""


def v_3d_anova3(
    type_: int,
    alevels: int,
    blevels: int,
    clevels: int,
    dsets: list[str],
    voxel_num: int | None = None,
    diskspace: bool = False,
    mask: InputPathType | None = None,
    anova_options: list[str] | None = None,
    runner: Runner | None = None,
) -> V3dAnova3Outputs:
    """
    Performs three-factor ANOVA on 3D data sets.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dANOVA3.html
    
    Args:
        type_: Type of ANOVA model to be used. k = 1: A,B,C fixed; AxBxC, k =\
            2: A,B,C random; AxBxC, k = 3: A fixed; B,C random; AxBxC, k = 4: A,B\
            fixed; C random; AxBxC, k = 5: A,B fixed; C random; AxB,BxC,C(A).
        alevels: Number of levels for factor A.
        blevels: Number of levels for factor B.
        clevels: Number of levels for factor C.
        dsets: Input data sets for specific levels of factors A, B, and C.
        voxel_num: Screen output for specified voxel number.
        diskspace: Print out disk space required for program execution.
        mask: Use sub-brick #0 of dataset to define which voxels to process.
        anova_options: Modified ANOVA computation options. See:\
            https://afni.nimh.nih.gov/sscc/gangc/ANOVA_Mod.html.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAnova3Outputs`).
    """
    if not (1 <= type_ <= 5): 
        raise ValueError(f"'type_' must be between 1 <= x <= 5 but was {type_}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ANOVA3_METADATA)
    cargs = []
    cargs.append("3dANOVA3")
    cargs.append("-type")
    cargs.extend([
        "-type",
        str(type_)
    ])
    cargs.append("-alevels")
    cargs.extend([
        "-alevels",
        str(alevels)
    ])
    cargs.append("-blevels")
    cargs.extend([
        "-blevels",
        str(blevels)
    ])
    cargs.append("-clevels")
    cargs.extend([
        "-clevels",
        str(clevels)
    ])
    cargs.extend([
        "-dset",
        *dsets
    ])
    if voxel_num is not None:
        cargs.extend([
            "-voxel",
            str(voxel_num)
        ])
    if diskspace:
        cargs.append("-diskspace")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append("[OUTFILES]")
    if anova_options is not None:
        cargs.extend([
            "-old_method -OK -assume_sph",
            *anova_options
        ])
    ret = V3dAnova3Outputs(
        root=execution.output_file("."),
        outfile_fa=execution.output_file("[OUTFILE_FA]"),
        outfile_fb=execution.output_file("[OUTFILE_FB]"),
        outfile_fc=execution.output_file("[OUTFILE_FC]"),
        outfile_fab=execution.output_file("[OUTFILE_FAB]"),
        outfile_fac=execution.output_file("[OUTFILE_FAC]"),
        outfile_fbc=execution.output_file("[OUTFILE_FBC]"),
        outfile_fabc=execution.output_file("[OUTFILE_FABC]"),
        outfile_amean=execution.output_file("[OUTFILE_AMEAN]"),
        outfile_bmean=execution.output_file("[OUTFILE_BMEAN]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAnova3Outputs",
    "V_3D_ANOVA3_METADATA",
    "v_3d_anova3",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FTOZ_METADATA = Metadata(
    id="f01afa9b8431b1163d41919afd62f2c7b9f742dd.boutiques",
    name="ftoz",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FtozOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ftoz(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_zscores: OutputPathType | None
    """File containing the converted Z-scores"""


def ftoz(
    input_file: InputPathType,
    dof1: float,
    dof2: float,
    output_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> FtozOutputs:
    """
    Convert F-statistics to Z-scores.
    
    Author: Unknown
    
    Args:
        input_file: File containing F-statistics.
        dof1: Degrees of freedom 1 for F-to-Z conversion.
        dof2: Degrees of freedom 2 for F-to-Z conversion.
        output_file: Output file for Z-scores.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FtozOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FTOZ_METADATA)
    cargs = []
    cargs.append("ftoz")
    cargs.append(execution.input_file(input_file))
    cargs.append(str(dof1))
    cargs.append(str(dof2))
    if output_file is not None:
        cargs.extend([
            "-zout",
            execution.input_file(output_file)
        ])
    ret = FtozOutputs(
        root=execution.output_file("."),
        output_zscores=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FTOZ_METADATA",
    "FtozOutputs",
    "ftoz",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WAVER_METADATA = Metadata(
    id="96b50e0c8292a4fbc3bac32ca89083846b0e7918.boutiques",
    name="waver",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class WaverOutputs(typing.NamedTuple):
    """
    Output object returned when calling `waver(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_filename: OutputPathType
    """The output filename for the result of the waveform."""


def waver(
    gam: bool = False,
    runner: Runner | None = None,
) -> WaverOutputs:
    """
    Creates an ideal waveform timeseries file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/waver.html
    
    Args:
        gam: Sets waveform to form t^b * exp(-t/c) (cf. Mark Cohen).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WaverOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WAVER_METADATA)
    cargs = []
    cargs.append("waver")
    if gam:
        cargs.append("-GAM")
    cargs.append("[OPTIONS]")
    cargs.append(">")
    cargs.append("[OUTPUT_FILENAME]")
    ret = WaverOutputs(
        root=execution.output_file("."),
        output_filename=execution.output_file("output_filename"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WAVER_METADATA",
    "WaverOutputs",
    "waver",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BEDPOSTX_GPU_METADATA = Metadata(
    id="1b7bc98054c569d66c0ab265626948c131ff30cd.boutiques",
    name="bedpostx_gpu",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class BedpostxGpuOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bedpostx_gpu(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bedpostx_gpu(
    subject_dir: str,
    gpu_queue: str | None = None,
    num_jobs: float | None = None,
    num_fibers: float | None = None,
    ard_weight: float | None = None,
    burnin_period: float | None = None,
    num_jumps: float | None = None,
    sample_every: float | None = None,
    deconv_model: float | None = None,
    grad_nonlinear: bool = False,
    runner: Runner | None = None,
) -> BedpostxGpuOutputs:
    """
    Probabilistic tractography and diffusion MRI fitting tool.
    
    Author: FMRIB Software Library (FSL)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FDT/Bedpostx
    
    Args:
        subject_dir: Directory containing the subject's DWI data and associated\
            files (bvals, bvecs, data, nodif_brain_mask).
        gpu_queue: Name of the GPU(s) queue. Default: --coprocessor=cuda to let\
            fsl_sub decide on the queue.
        num_jobs: Number of jobs to queue. The data is divided into this number\
            of parts, useful for a GPU cluster. Default: 4.
        num_fibers: Number of fibres per voxel. Default: 3.
        ard_weight: Automatic Relevance Determination (ARD) weight. More weight\
            means fewer secondary fibres per voxel. Default: 1.
        burnin_period: Burn-in period. Default: 1000.
        num_jumps: Number of jumps. Default: 1250.
        sample_every: Sample every N steps. Default: 25.
        deconv_model: Deconvolution model. 1: with sticks, 2: with sticks with\
            a range of diffusivities (default), 3: with zeppelins.
        grad_nonlinear: Consider gradient nonlinearities. Default: off.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BedpostxGpuOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BEDPOSTX_GPU_METADATA)
    cargs = []
    cargs.append("bedpostx")
    cargs.append(subject_dir)
    if gpu_queue is not None:
        cargs.extend([
            "-Q",
            gpu_queue
        ])
    if num_jobs is not None:
        cargs.extend([
            "-NJOBS",
            str(num_jobs)
        ])
    if num_fibers is not None:
        cargs.extend([
            "-n",
            str(num_fibers)
        ])
    if ard_weight is not None:
        cargs.extend([
            "-w",
            str(ard_weight)
        ])
    if burnin_period is not None:
        cargs.extend([
            "-b",
            str(burnin_period)
        ])
    if num_jumps is not None:
        cargs.extend([
            "-j",
            str(num_jumps)
        ])
    if sample_every is not None:
        cargs.extend([
            "-s",
            str(sample_every)
        ])
    if deconv_model is not None:
        cargs.extend([
            "-model",
            str(deconv_model)
        ])
    if grad_nonlinear:
        cargs.append("-g")
    ret = BedpostxGpuOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BEDPOSTX_GPU_METADATA",
    "BedpostxGpuOutputs",
    "bedpostx_gpu",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_INTERPMOT_PY_METADATA = Metadata(
    id="c34391e653c9cbe437b81104094754d85af56ce2.boutiques",
    name="possum_interpmot.py",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PossumInterpmotPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum_interpmot_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Interpolated motion output file"""


def possum_interpmot_py(
    motion_type: int,
    tr: float,
    tr_slice: float,
    nslices: int,
    nvols: int,
    custom_motion_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> PossumInterpmotPyOutputs:
    """
    Position Interpolation for Movers and Shakers.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk
    
    Args:
        motion_type: Type of motion: 0 for continuous, 1 for between slices, 2\
            for between volumes.
        tr: Repetition time in seconds.
        tr_slice: Slice repetition time in seconds.
        nslices: Number of slices.
        nvols: Number of volumes.
        custom_motion_file: Custom motion file.
        output_file: Output file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumInterpmotPyOutputs`).
    """
    if not (0 <= motion_type <= 2): 
        raise ValueError(f"'motion_type' must be between 0 <= x <= 2 but was {motion_type}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_INTERPMOT_PY_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/possum_interpmot.py")
    cargs.append(str(motion_type))
    cargs.append(str(tr))
    cargs.append(str(tr_slice))
    cargs.append(str(nslices))
    cargs.append(str(nvols))
    cargs.append(execution.input_file(custom_motion_file))
    cargs.append(output_file)
    ret = PossumInterpmotPyOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_INTERPMOT_PY_METADATA",
    "PossumInterpmotPyOutputs",
    "possum_interpmot_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AUTOBOX_METADATA = Metadata(
    id="ecb09df00b41a530e66f1496b998bf28f67fb02d.boutiques",
    name="3dAutobox",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAutoboxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_autobox(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_autobox(
    input_: InputPathType,
    runner: Runner | None = None,
) -> V3dAutoboxOutputs:
    """
    Computes size of a box that fits around the volume. Can also be used to crop the
    volume to that box.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAutobox.html
    
    Args:
        input_: Input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAutoboxOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AUTOBOX_METADATA)
    cargs = []
    cargs.append("3dAutobox")
    cargs.append("[OPTIONS]")
    cargs.append(execution.input_file(input_))
    ret = V3dAutoboxOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAutoboxOutputs",
    "V_3D_AUTOBOX_METADATA",
    "v_3d_autobox",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFMATHS_METADATA = Metadata(
    id="b8ae24d5ed4caf90d6715b600edc707e3ecce266.boutiques",
    name="surfmaths",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SurfmathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surfmaths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output surface file generated by the tool."""


def surfmaths(
    first_input: InputPathType,
    output: InputPathType,
    operations_inputs: list[str] | None = None,
    runner: Runner | None = None,
) -> SurfmathsOutputs:
    """
    A command-line tool for performing various mathematical operations on surface
    files.
    
    Args:
        first_input: First input surface file.
        output: Output surface file.
        operations_inputs: Mathematical operations and additional inputs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfmathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFMATHS_METADATA)
    cargs = []
    cargs.append("surfmaths")
    cargs.append(execution.input_file(first_input))
    if operations_inputs is not None:
        cargs.extend(operations_inputs)
    cargs.append(execution.input_file(output))
    ret = SurfmathsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFMATHS_METADATA",
    "SurfmathsOutputs",
    "surfmaths",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_FILE_EXPORT_TO_CARET5_METADATA = Metadata(
    id="9ffbf7cf99c11004cb0ea971687cc61eb7a32eec.boutiques",
    name="border-file-export-to-caret5",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class BorderFileExportToCaret5Surface:
    """
    specify an input surface.
    """
    surface_in: InputPathType
    """a surface file for unprojection of borders"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface")
        cargs.append(execution.input_file(self.surface_in))
        return cargs


class BorderFileExportToCaret5Outputs(typing.NamedTuple):
    """
    Output object returned when calling `border_file_export_to_caret5(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_file_export_to_caret5(
    border_file: str,
    output_file_prefix: str,
    surface: list[BorderFileExportToCaret5Surface] | None = None,
    runner: Runner | None = None,
) -> BorderFileExportToCaret5Outputs:
    """
    Export border file to caret5 file format.
    
    A Workbench border file may contain borders for multiple structures and
    borders that are both projected and unprojected. It also contains a color
    table for the borders.
    
    Caret5 has both border (unprojected) and border projection (projected)
    files. In addition, each Caret5 border or border projection file typically
    contains data for a single structure. Caret5 also uses a border color file
    that associates colors with the names of the borders.
    
    This command will try to output both Caret5 border and border projection
    files. Each output border/border projection file will contains data for one
    structure so there may be many files created. The structure name is included
    in the name of each border or border projection file that is created.
    
    One Caret5 border color file will also be produced by this command.
    
    Providing surface(s) as input parameters is optional, but recommended.
    Surfaces may be needed to create both projected and/or unprojected
    coordinates of borders. If there is a failure to produce an output border or
    border projection due to a missing surface with the matching structure, an
    error message will be displayed and some output files will not be created.
    
    When writing new files, this command will overwrite a file with the same
    name. .
    
    Author: Washington University School of Medicin
    
    Args:
        border_file: workbench border file.
        output_file_prefix: prefix for name of output caret5\
            border/borderproj/bordercolor files.
        surface: specify an input surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderFileExportToCaret5Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_FILE_EXPORT_TO_CARET5_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-file-export-to-caret5")
    cargs.append(border_file)
    cargs.append(output_file_prefix)
    if surface is not None:
        cargs.extend([a for c in [s.run(execution) for s in surface] for a in c])
    ret = BorderFileExportToCaret5Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_FILE_EXPORT_TO_CARET5_METADATA",
    "BorderFileExportToCaret5Outputs",
    "BorderFileExportToCaret5Surface",
    "border_file_export_to_caret5",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BORDER_EXPORT_COLOR_TABLE_METADATA = Metadata(
    id="731f1fc5b0c0ca46d740510ab287e981975ddd70.boutiques",
    name="border-export-color-table",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class BorderExportColorTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `border_export_color_table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def border_export_color_table(
    border_file: InputPathType,
    table_out: str,
    opt_class_colors: bool = False,
    runner: Runner | None = None,
) -> BorderExportColorTableOutputs:
    """
    Write border names and colors as text.
    
    Takes the names and colors of each border, and writes it to the same format
    as -metric-label-import expects. By default, the borders are colored by
    border name, specify -class-colors to color them by class instead. The key
    values start at 1 and follow the order of the borders in the file.
    
    Author: Washington University School of Medicin
    
    Args:
        border_file: the input border file.
        table_out: output - the output text file.
        opt_class_colors: use class colors instead of the name colors.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BorderExportColorTableOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BORDER_EXPORT_COLOR_TABLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-border-export-color-table")
    cargs.append(execution.input_file(border_file))
    cargs.append(table_out)
    if opt_class_colors:
        cargs.append("-class-colors")
    ret = BorderExportColorTableOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BORDER_EXPORT_COLOR_TABLE_METADATA",
    "BorderExportColorTableOutputs",
    "border_export_color_table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ASL_MFREE_METADATA = Metadata(
    id="3df5c70b713c669c2cd52fa754362efc300e770e.boutiques",
    name="asl_mfree",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class AslMfreeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `asl_mfree(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    result_file: OutputPathType
    """Output results from ASL model-free analysis"""
    bat_img: OutputPathType
    """Estimated tissue BAT image file"""


def asl_mfree(
    datafile: InputPathType,
    mask: InputPathType,
    out: str,
    aif: InputPathType,
    dt: float,
    metric: InputPathType | None = None,
    mthresh: float | None = None,
    tcorrect: bool = False,
    bata: InputPathType | None = None,
    batt: InputPathType | None = None,
    bat: bool = False,
    bat_grad_thr: float | None = 0.2,
    t1: float | None = None,
    fa: float | None = None,
    std: bool = False,
    nwb: float | None = None,
    turbo_quasar: bool = False,
    shift_factor: float | None = 1,
    runner: Runner | None = None,
) -> AslMfreeOutputs:
    """
    ASL model-free analysis tool.
    
    Author: FMRIB Centre, University of Oxford
    
    Args:
        datafile: ASL data file.
        mask: Mask file.
        out: Output directory name.
        aif: Arterial input functions for deconvolution (4D volume, one aif for\
            each voxel within mask).
        dt: Temporal spacing in data (s).
        metric: Metric image file (optional).
        mthresh: Metric threshold (optional).
        tcorrect: Apply correction for timing difference between AIF and tissue\
            curve (optional).
        bata: Arterial BAT image (optional).
        batt: Tissue BAT image (optional).
        bat: Estimate tissue BAT from data and save this image (optional).
        bat_grad_thr: Edge detection gradient threshold (default: 0.2,\
            optional).
        t1: T1 (of blood) value (optional).
        fa: Flip angle (if using LL readout, optional).
        std: Calculate standard deviations on perfusion values using wild\
            bootstrapping (optional).
        nwb: Number of permutations for wild bootstrapping (optional).
        turbo_quasar: Specify this is a Turbo QUASAR Sequence (optional).
        shift_factor: Slice shifting factor in Turbo QUASAR (default value: 1,\
            optional).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AslMfreeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ASL_MFREE_METADATA)
    cargs = []
    cargs.append("asl_mfree")
    cargs.extend([
        "--data",
        execution.input_file(datafile)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(mask)
    ])
    cargs.extend([
        "--out",
        out
    ])
    cargs.extend([
        "--aif",
        execution.input_file(aif)
    ])
    cargs.extend([
        "--dt",
        str(dt)
    ])
    if metric is not None:
        cargs.extend([
            "--metric",
            execution.input_file(metric)
        ])
    if mthresh is not None:
        cargs.extend([
            "--mthresh",
            str(mthresh)
        ])
    if tcorrect:
        cargs.append("--tcorrect")
    if bata is not None:
        cargs.extend([
            "--bata",
            execution.input_file(bata)
        ])
    if batt is not None:
        cargs.extend([
            "--batt",
            execution.input_file(batt)
        ])
    if bat:
        cargs.append("--bat")
    if bat_grad_thr is not None:
        cargs.extend([
            "--bat_grad_thr",
            str(bat_grad_thr)
        ])
    if t1 is not None:
        cargs.extend([
            "--t1",
            str(t1)
        ])
    if fa is not None:
        cargs.extend([
            "--fa",
            str(fa)
        ])
    if std:
        cargs.append("--std")
    if nwb is not None:
        cargs.extend([
            "--nwb",
            str(nwb)
        ])
    if turbo_quasar:
        cargs.append("--turbo_quasar")
    if shift_factor is not None:
        cargs.extend([
            "--shift_factor",
            str(shift_factor)
        ])
    cargs.append("--verbose")
    ret = AslMfreeOutputs(
        root=execution.output_file("."),
        result_file=execution.output_file(out + "/results.nii.gz"),
        bat_img=execution.output_file(out + "/bat.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ASL_MFREE_METADATA",
    "AslMfreeOutputs",
    "asl_mfree",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_2D_IM_REG_METADATA = Metadata(
    id="eb09199ec4bc407db9b8b93db9712dbe484d6202.boutiques",
    name="2dImReg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V2dImRegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_2d_im_reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType
    """Output 3d+time dataset"""
    dx_file: OutputPathType | None
    """File containing dx registration parameters in pixels/mm"""
    dy_file: OutputPathType | None
    """File containing dy registration parameters in pixels/mm"""
    psi_file: OutputPathType | None
    """File containing psi registration parameters in degrees"""
    oldrms_file: OutputPathType | None
    """File containing the volume RMS error for the original dataset"""
    newrms_file: OutputPathType | None
    """File containing the volume RMS error for the registered dataset"""


def v_2d_im_reg(
    input_file: InputPathType,
    prefix: str,
    base_file: InputPathType | None = None,
    base: float | None = None,
    nofine: bool = False,
    fine_blur: float | None = None,
    fine_dxy: float | None = None,
    fine_dphi: float | None = None,
    dprefix: str | None = None,
    dmm: bool = False,
    rprefix: str | None = None,
    debug: bool = False,
    runner: Runner | None = None,
) -> V2dImRegOutputs:
    """
    2D image registration tool for 3D+time datasets, aligning images on a
    slice-by-slice basis to a specified base image.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/2dImReg.html
    
    Args:
        input_file: Filename of input 3d+time dataset to process.
        prefix: Prefix name for output 3d+time dataset.
        base_file: Filename of 3d+time dataset for base image (default =\
            current input dataset).
        base: Time index for base image (0 <= num) (default: num = 3).
        nofine: Deactivate fine fit phase of image registration (default: fine\
            fit is active).
        fine_blur: FWHM of blurring prior to registration (in pixels) (default:\
            blur = 1.0).
        fine_dxy: Convergence tolerance for translations (in pixels) (default:\
            dxy = 0.07).
        fine_dphi: Convergence tolerance for rotations (in degrees) (default:\
            dphi = 0.21).
        dprefix: Write files containing the registration parameters for each\
            slice in chronological order.
        dmm: Change dx and dy output format from pixels to mm.
        rprefix: Write files containing the volume RMS error for the original\
            and the registered datasets.
        debug: Lots of additional output to screen.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V2dImRegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_2D_IM_REG_METADATA)
    cargs = []
    cargs.append("2dImReg")
    cargs.append(execution.input_file(input_file))
    if base_file is not None:
        cargs.append(execution.input_file(base_file))
    if base is not None:
        cargs.append(str(base))
    if nofine:
        cargs.append("-nofine")
    if fine_blur is not None:
        cargs.append(str(fine_blur))
    if fine_dxy is not None:
        cargs.append(str(fine_dxy))
    if fine_dphi is not None:
        cargs.append(str(fine_dphi))
    cargs.append(prefix)
    if dprefix is not None:
        cargs.append(dprefix)
    if dmm:
        cargs.append("-dmm")
    if rprefix is not None:
        cargs.append(rprefix)
    if debug:
        cargs.append("-debug")
    ret = V2dImRegOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + ".nii"),
        dx_file=execution.output_file(dprefix + ".dx") if (dprefix is not None) else None,
        dy_file=execution.output_file(dprefix + ".dy") if (dprefix is not None) else None,
        psi_file=execution.output_file(dprefix + ".psi") if (dprefix is not None) else None,
        oldrms_file=execution.output_file(rprefix + ".oldrms") if (rprefix is not None) else None,
        newrms_file=execution.output_file(rprefix + ".newrms") if (rprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V2dImRegOutputs",
    "V_2D_IM_REG_METADATA",
    "v_2d_im_reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENA_METADATA = Metadata(
    id="f563d34242a20a59b19c40b577e68df6fe81618c.boutiques",
    name="siena",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class SienaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `siena(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_report: OutputPathType | None
    """Siena analysis report"""
    ventricle_analysis_report: OutputPathType | None
    """Siena ventricle analysis report"""


def siena(
    input1: InputPathType,
    input2: InputPathType,
    output_dir: str | None = None,
    debug_flag: bool = False,
    bet_options: str | None = None,
    two_class_seg_flag: bool = False,
    t2_weighted_flag: bool = False,
    standard_space_mask_flag: bool = False,
    upper_ignore: float | None = None,
    lower_ignore: float | None = None,
    sienadiff_options: str | None = None,
    ventricle_analysis_flag: bool = False,
    ventricle_mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> SienaOutputs:
    """
    Structural Image Evaluation, using Normalization, of Atrophy tool for evaluating
    brain atrophy between two timepoints.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/SIENA
    
    Args:
        input1: First input image (e.g. timepoint 1 image, img1.nii.gz).
        input2: Second input image (e.g. timepoint 2 image, img2.nii.gz).
        output_dir: Set output directory (default output is\
            <input1>_to_<input2>_siena).
        debug_flag: Debug (don't delete intermediate files).
        bet_options: Options to pass to BET brain extraction (inside\
            double-quotes), e.g. -B "-f 0.3".
        two_class_seg_flag: Two-class segmentation (don't segment grey and\
            white matter separately).
        t2_weighted_flag: T2-weighted input image (default T1-weighted).
        standard_space_mask_flag: Use standard-space masking as well as BET.
        upper_ignore: Ignore from t (mm) upwards in MNI152/Talairach space.
        lower_ignore: Ignore from b (mm) downwards in MNI152/Talairach space (b\
            should probably be negative).
        sienadiff_options: Options to pass to siena_diff timepoint differencing\
            (inside double-quotes), e.g. -S "-s -i 20".
        ventricle_analysis_flag: Run ventricle analysis (VIENA).
        ventricle_mask: Optional user-supplied ventricle mask (default is\
            /usr/local/fsl/data/standard/MNI152_T1_2mm_VentricleMask).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENA_METADATA)
    cargs = []
    cargs.append("siena")
    cargs.append(execution.input_file(input1))
    cargs.append(execution.input_file(input2))
    if output_dir is not None:
        cargs.extend([
            "-o",
            output_dir
        ])
    if debug_flag:
        cargs.append("-d")
    if bet_options is not None:
        cargs.extend([
            "-B",
            bet_options
        ])
    if two_class_seg_flag:
        cargs.append("-2")
    if t2_weighted_flag:
        cargs.append("-t2")
    if standard_space_mask_flag:
        cargs.append("-m")
    if upper_ignore is not None:
        cargs.extend([
            "-t",
            str(upper_ignore)
        ])
    if lower_ignore is not None:
        cargs.extend([
            "-b",
            str(lower_ignore)
        ])
    if sienadiff_options is not None:
        cargs.extend([
            "-S",
            sienadiff_options
        ])
    if ventricle_analysis_flag:
        cargs.append("-V")
    if ventricle_mask is not None:
        cargs.extend([
            "-v",
            execution.input_file(ventricle_mask)
        ])
    ret = SienaOutputs(
        root=execution.output_file("."),
        output_report=execution.output_file(output_dir + "/report.html") if (output_dir is not None) else None,
        ventricle_analysis_report=execution.output_file(output_dir + "/report_vent.html") if (output_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENA_METADATA",
    "SienaOutputs",
    "siena",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DWI2FOD_METADATA = Metadata(
    id="5980da20b52fc84cfec9e652fca13e33939bddb1.boutiques",
    name="dwi2fod",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class Dwi2fodFslgrad:
    """
    Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used.
    """
    bvecs: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    bvals: InputPathType
    """Provide the diffusion-weighted gradient scheme used in the acquisition in
    FSL bvecs/bvals format files. If a diffusion gradient scheme is present in
    the input image header, the data provided with this option will be instead
    used."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-fslgrad")
        cargs.append(execution.input_file(self.bvecs))
        cargs.append(execution.input_file(self.bvals))
        return cargs


@dataclasses.dataclass
class Dwi2fodConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class Dwi2fodResponseOdfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `list[Dwi2fodResponseOdf](...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    odf: OutputPathType
    """output ODF image"""


@dataclasses.dataclass
class Dwi2fodResponseOdf:
    """
    pairs of input tissue response and output ODF images.
    """
    response: InputPathType
    """input tissue response"""
    odf: str
    """output ODF image"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.response))
        cargs.append(self.odf)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> Dwi2fodResponseOdfOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `Dwi2fodResponseOdfOutputs`).
        """
        ret = Dwi2fodResponseOdfOutputs(
            root=execution.output_file("."),
            odf=execution.output_file(self.odf),
        )
        return ret


class Dwi2fodOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dwi2fod(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    predicted_signal: OutputPathType | None
    """output the predicted dwi image. """
    response_odf: typing.List[Dwi2fodResponseOdfOutputs]
    """Outputs from `Dwi2fodResponseOdf`.This is a list of outputs with the same
    length and order as the inputs."""


def dwi2fod(
    algorithm: str,
    dwi: InputPathType,
    response_odf: list[Dwi2fodResponseOdf],
    grad: InputPathType | None = None,
    fslgrad: Dwi2fodFslgrad | None = None,
    shells: list[float] | None = None,
    directions: InputPathType | None = None,
    lmax: list[int] | None = None,
    mask: InputPathType | None = None,
    filter_: InputPathType | None = None,
    neg_lambda: float | None = None,
    norm_lambda: float | None = None,
    threshold: float | None = None,
    niter: int | None = None,
    norm_lambda_: float | None = None,
    neg_lambda_: float | None = None,
    predicted_signal: str | None = None,
    strides: str | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[Dwi2fodConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> Dwi2fodOutputs:
    """
    Estimate fibre orientation distributions from diffusion data using spherical
    deconvolution.
    
    The spherical harmonic coefficients are stored according the conventions
    described the main documentation, which can be found at the following link:
    https://mrtrix.readthedocs.io/en/3.0.4/concepts/spherical_harmonics.html
    
    References:
    
    * If using csd algorithm:
    Tournier, J.-D.; Calamante, F. & Connelly, A. Robust determination of the
    fibre orientation distribution in diffusion MRI: Non-negativity constrained
    super-resolved spherical deconvolution. NeuroImage, 2007, 35, 1459-1472
    
    * If using msmt_csd algorithm:
    Jeurissen, B; Tournier, J-D; Dhollander, T; Connelly, A & Sijbers, J.
    Multi-tissue constrained spherical deconvolution for improved analysis of
    multi-shell diffusion MRI data. NeuroImage, 2014, 103, 411-426
    
    Tournier, J.-D.; Calamante, F., Gadian, D.G. & Connelly, A. Direct
    estimation of the fiber orientation density function from diffusion-weighted
    MRI data using spherical deconvolution. NeuroImage, 2004, 23, 1176-1185.
    
    Author: J-Donald Tournier (jdtournier@gmail.com) and Ben Jeurissen
    (ben.jeurissen@uantwerpen.be)
    
    URL: https://mrtrix.readthedocs.io/en/latest/reference/commands/dwi2fod.html
    
    Args:
        algorithm: the algorithm to use for FOD estimation. (options are:\
            csd,msmt_csd).
        dwi: the input diffusion-weighted image.
        response_odf: pairs of input tissue response and output ODF images.
        grad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in a text file. This should be supplied as a 4xN text file\
            with each line is in the format [ X Y Z b ], where [ X Y Z ] describe\
            the direction of the applied gradient, and b gives the b-value in units\
            of s/mm^2. If a diffusion gradient scheme is present in the input image\
            header, the data provided with this option will be instead used.
        fslgrad: Provide the diffusion-weighted gradient scheme used in the\
            acquisition in FSL bvecs/bvals format files. If a diffusion gradient\
            scheme is present in the input image header, the data provided with\
            this option will be instead used.
        shells: specify one or more b-values to use during processing, as a\
            comma-separated list of the desired approximate b-values (b-values are\
            clustered to allow for small deviations). Note that some commands are\
            incompatible with multiple b-values, and will report an error if more\
            than one b-value is provided.\
            WARNING: note that, even though the b=0 volumes are never referred\
            to as shells in the literature, they still have to be explicitly\
            included in the list of b-values as provided to the -shell option!\
            Several algorithms which include the b=0 volumes in their\
            computations may otherwise return an undesired result.
        directions: specify the directions over which to apply the\
            non-negativity constraint (by default, the built-in 300 direction set\
            is used). These should be supplied as a text file containing [ az el ]\
            pairs for the directions.
        lmax: the maximum spherical harmonic order for the output FOD(s).For\
            algorithms with multiple outputs, this should be provided as a\
            comma-separated list of integers, one for each output image; for\
            single-output algorithms, only a single integer should be provided. If\
            omitted, the command will use the lmax of the corresponding response\
            function (i.e based on its number of coefficients), up to a maximum of\
            8.
        mask: only perform computation within the specified binary brain mask\
            image.
        filter_: the linear frequency filtering parameters used for the initial\
            linear spherical deconvolution step (default = [ 1 1 1 0 0 ]). These\
            should be supplied as a text file containing the filtering coefficients\
            for each even harmonic order.
        neg_lambda: the regularisation parameter lambda that controls the\
            strength of the non-negativity constraint (default = 1).
        norm_lambda: the regularisation parameter lambda that controls the\
            strength of the constraint on the norm of the solution (default = 1).
        threshold: the threshold below which the amplitude of the FOD is\
            assumed to be zero, expressed as an absolute amplitude (default = 0).
        niter: the maximum number of iterations to perform for each voxel\
            (default = 50). Use '-niter 0' for a linear unconstrained spherical\
            deconvolution.
        norm_lambda_: the regularisation parameter lambda that controls the\
            strength of the constraint on the norm of the solution (default =\
            1e-10).
        neg_lambda_: the regularisation parameter lambda that controls the\
            strength of the non-negativity constraint (default = 1e-10).
        predicted_signal: output the predicted dwi image.
        strides: specify the strides of the output data in memory; either as a\
            comma-separated list of (signed) integers, or as a template image from\
            which the strides shall be extracted and used. The actual strides\
            produced will depend on whether the output image format can support it.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Dwi2fodOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DWI2FOD_METADATA)
    cargs = []
    cargs.append("dwi2fod")
    if grad is not None:
        cargs.extend([
            "-grad",
            execution.input_file(grad)
        ])
    if fslgrad is not None:
        cargs.extend(fslgrad.run(execution))
    if shells is not None:
        cargs.extend([
            "-shells",
            ",".join(map(str, shells))
        ])
    if directions is not None:
        cargs.extend([
            "-directions",
            execution.input_file(directions)
        ])
    if lmax is not None:
        cargs.extend([
            "-lmax",
            ",".join(map(str, lmax))
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if filter_ is not None:
        cargs.extend([
            "-filter",
            execution.input_file(filter_)
        ])
    if neg_lambda is not None:
        cargs.extend([
            "-neg_lambda",
            str(neg_lambda)
        ])
    if norm_lambda is not None:
        cargs.extend([
            "-norm_lambda",
            str(norm_lambda)
        ])
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if niter is not None:
        cargs.extend([
            "-niter",
            str(niter)
        ])
    if norm_lambda_ is not None:
        cargs.extend([
            "-norm_lambda",
            str(norm_lambda_)
        ])
    if neg_lambda_ is not None:
        cargs.extend([
            "-neg_lambda",
            str(neg_lambda_)
        ])
    if predicted_signal is not None:
        cargs.extend([
            "-predicted_signal",
            predicted_signal
        ])
    if strides is not None:
        cargs.extend([
            "-strides",
            strides
        ])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(algorithm)
    cargs.append(execution.input_file(dwi))
    cargs.extend([a for c in [s.run(execution) for s in response_odf] for a in c])
    ret = Dwi2fodOutputs(
        root=execution.output_file("."),
        predicted_signal=execution.output_file(predicted_signal) if (predicted_signal is not None) else None,
        response_odf=[i.outputs(execution) for i in response_odf],
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DWI2FOD_METADATA",
    "Dwi2fodConfig",
    "Dwi2fodFslgrad",
    "Dwi2fodOutputs",
    "Dwi2fodResponseOdf",
    "Dwi2fodResponseOdfOutputs",
    "dwi2fod",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_3D_PFM_DEMO_METADATA = Metadata(
    id="0f9cb4b2fe5d3ed4f3ad4eca9fb9d2d2fb453961.boutiques",
    name="@Install_3dPFM_Demo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstall3dPfmDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_3d_pfm_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    readme_file: OutputPathType
    """Instructions for demo usage"""


def v__install_3d_pfm_demo(
    output_directory: str,
    runner: Runner | None = None,
) -> VInstall3dPfmDemoOutputs:
    """
    Installs the demo archive for the 3dPFM function.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_3dPFM_Demo.html
    
    Args:
        output_directory: Output directory where the demo archive will be\
            downloaded and unpacked.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstall3dPfmDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_3D_PFM_DEMO_METADATA)
    cargs = []
    cargs.append("Install_3dPFM_Demo")
    cargs.append(output_directory)
    ret = VInstall3dPfmDemoOutputs(
        root=execution.output_file("."),
        readme_file=execution.output_file(output_directory + "/README.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstall3dPfmDemoOutputs",
    "V__INSTALL_3D_PFM_DEMO_METADATA",
    "v__install_3d_pfm_demo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_APMULTI_DEMO2_REALTIME_METADATA = Metadata(
    id="35a4473905976e57395c02879ed22abe1b49a7c1.boutiques",
    name="@Install_APMULTI_Demo2_realtime",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallApmultiDemo2RealtimeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_apmulti_demo2_realtime(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_apmulti_demo2_realtime(
    curl: bool = False,
    runner: Runner | None = None,
) -> VInstallApmultiDemo2RealtimeOutputs:
    """
    Fetches the demo data and scripts corresponding to AFNI's Demo #2 for
    experimenting with AFNI's real-time system.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_APMULTI_Demo2_realtime.html
    
    Args:
        curl: Use curl to download the archive. By default, the script prefers\
            curl.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallApmultiDemo2RealtimeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_APMULTI_DEMO2_REALTIME_METADATA)
    cargs = []
    cargs.append("@Install_APMULTI_Demo2_realtime")
    if curl:
        cargs.append("-curl")
    ret = VInstallApmultiDemo2RealtimeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallApmultiDemo2RealtimeOutputs",
    "V__INSTALL_APMULTI_DEMO2_REALTIME_METADATA",
    "v__install_apmulti_demo2_realtime",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SURF_MASK_METADATA = Metadata(
    id="b8441ef0584a7bf83b118f6db3b81eb258eacb78.boutiques",
    name="3dSurfMask",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSurfMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_surf_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType
    """Main output mask dataset."""
    distance_dataset: OutputPathType
    """Dataset reflecting voxel shortest distances to the surface."""


def v_3d_surf_mask(
    runner: Runner | None = None,
) -> V3dSurfMaskOutputs:
    """
    Creates volumetric datasets marking voxels based on their location relative to a
    surface.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dSurfMask.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSurfMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SURF_MASK_METADATA)
    cargs = []
    cargs.append("3dSurfMask")
    cargs.append("<-i_TYPE")
    cargs.append("SURFACE>")
    cargs.append("<-prefix")
    cargs.append("PREFIX>")
    cargs.append("<-grid_parent")
    cargs.append("GRID_VOL>")
    cargs.append("[<fill_method>")
    cargs.append("<SURF_VOL>")
    cargs.append("<mask_only>")
    cargs.append("<flip_orientation>")
    cargs.append("<no_dist>]")
    ret = V3dSurfMaskOutputs(
        root=execution.output_file("."),
        output_mask=execution.output_file("[PREFIX].m+orig.BRIK"),
        distance_dataset=execution.output_file("[PREFIX].d+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSurfMaskOutputs",
    "V_3D_SURF_MASK_METADATA",
    "v_3d_surf_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_REMOVE_ISLANDS_METADATA = Metadata(
    id="084bad58202e9e9fb402a13dbc455d0bdb7e9a3f.boutiques",
    name="volume-remove-islands",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeRemoveIslandsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_remove_islands(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output ROI volume"""


def volume_remove_islands(
    volume_in: InputPathType,
    volume_out: str,
    runner: Runner | None = None,
) -> VolumeRemoveIslandsOutputs:
    """
    Remove islands from an roi volume.
    
    Finds all face-connected parts of the ROI, and zeros out all but the largest
    one.
    
    Author: Washington University School of Medicin
    
    Args:
        volume_in: the input ROI volume.
        volume_out: the output ROI volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeRemoveIslandsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_REMOVE_ISLANDS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-remove-islands")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_out)
    ret = VolumeRemoveIslandsOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_REMOVE_ISLANDS_METADATA",
    "VolumeRemoveIslandsOutputs",
    "volume_remove_islands",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_INSTA_CORR_DEMO_METADATA = Metadata(
    id="7f4f6b252fff2b3ada398e7114eeff68065918dd.boutiques",
    name="@Install_InstaCorr_Demo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallInstaCorrDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_insta_corr_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_insta_corr_demo(
    wget: bool = False,
    curl: bool = False,
    full: bool = False,
    mini: bool = False,
    runner: Runner | None = None,
) -> VInstallInstaCorrDemoOutputs:
    """
    Installs and sets up AFNI's InstaCorr demo archive.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_InstaCorr_Demo.html
    
    Args:
        wget: Use wget to download archive. Script chooses by default with\
            preference for curl.
        curl: Use curl to download archive. Script chooses by default with\
            preference for curl.
        full: Install the full version of the demo. Downloads all subject\
            surfaces, resting state volume time series, etc. The script processes\
            the data and produces the files needed for running the various\
            interactive InstaCorr demos.
        mini: Install the mini version of the demo. Downloads only the files\
            needed for running the various interactive InstaCorr demos.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallInstaCorrDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_INSTA_CORR_DEMO_METADATA)
    cargs = []
    cargs.append("@Install_InstaCorr_Demo")
    if wget:
        cargs.append("-wget")
    if curl:
        cargs.append("-curl")
    if full:
        cargs.append("-full")
    if mini:
        cargs.append("-mini")
    ret = VInstallInstaCorrDemoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallInstaCorrDemoOutputs",
    "V__INSTALL_INSTA_CORR_DEMO_METADATA",
    "v__install_insta_corr_demo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CLIP_VOLUME_METADATA = Metadata(
    id="34b4f197f772d15d186d100183958d1eb07e4783.boutiques",
    name="@clip_volume",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VClipVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__clip_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_clipped_volume: OutputPathType | None
    """Output clipped or cropped volume"""
    output_followers: OutputPathType | None
    """Output for follower datasets after clipping/cropping"""


def v__clip_volume(
    input_volume: InputPathType,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> VClipVolumeOutputs:
    """
    A tool to clip regions of a volume in various ways, such as above/below certain
    coordinates or within a specified box.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@clip_volume.html
    
    Args:
        input_volume: Volume to clip.
        output_prefix: Output prefix for the resultant volume. Default is the\
            input prefix with _clp suffixed to it.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VClipVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CLIP_VOLUME_METADATA)
    cargs = []
    cargs.append("@clip_volume")
    cargs.append("-input")
    cargs.append(execution.input_file(input_volume))
    cargs.append("[CLIPPING_OPTIONS]")
    cargs.append("[LOGIC_OPTIONS]")
    cargs.append("[CROP_OPTIONS]")
    cargs.append("-prefix")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    ret = VClipVolumeOutputs(
        root=execution.output_file("."),
        output_clipped_volume=execution.output_file(output_prefix + "_clp.nii.gz") if (output_prefix is not None) else None,
        output_followers=execution.output_file(output_prefix + "_follow_clp.nii.gz") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VClipVolumeOutputs",
    "V__CLIP_VOLUME_METADATA",
    "v__clip_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_ORIENT2_RAIMAP_METADATA = Metadata(
    id="e92e9346aeccdf0f687d1075a453b85d55530442.boutiques",
    name="@AfniOrient2RAImap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniOrient2RaimapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_orient2_raimap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__afni_orient2_raimap(
    orientation_code: str,
    runner: Runner | None = None,
) -> VAfniOrient2RaimapOutputs:
    """
    Returns the index map for the RAI directions.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@AfniOrient2RAImap.html
    
    Args:
        orientation_code: Orientation code (e.g., RAI, LSP).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniOrient2RaimapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_ORIENT2_RAIMAP_METADATA)
    cargs = []
    cargs.append("@AfniOrient2RAImap")
    cargs.append(orientation_code)
    ret = VAfniOrient2RaimapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniOrient2RaimapOutputs",
    "V__AFNI_ORIENT2_RAIMAP_METADATA",
    "v__afni_orient2_raimap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AFNITO_NIFTI_METADATA = Metadata(
    id="fb3d635db1319933a6531cd04ac8e966302fa609.boutiques",
    name="3dAFNItoNIFTI",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAfnitoNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_afnito_nifti(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_nifti: OutputPathType | None
    """Output NIfTI file."""


def v_3d_afnito_nifti(
    input_dataset: InputPathType,
    prefix: str | None = None,
    verbose: bool = False,
    force_float: bool = False,
    pure: bool = False,
    denote: bool = False,
    oldid: bool = False,
    newid: bool = False,
    runner: Runner | None = None,
) -> V3dAfnitoNiftiOutputs:
    """
    Converts an AFNI dataset to a NIfTI-1.1 file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dAFNItoNIFTI.html
    
    Args:
        input_dataset: Input AFNI dataset.
        prefix: Output NIfTI file prefix.
        verbose: Print progress messages (increases verbosity if repeated).
        force_float: Force the output dataset to be 32-bit floats.
        pure: Do not write an AFNI extension field into the output file.
        denote: Remove text notes from AFNI extension field that might contain\
            identifying information.
        oldid: Retain the input dataset's AFNI ID code.
        newid: Assign a new AFNI ID code to the dataset (default action).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAfnitoNiftiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AFNITO_NIFTI_METADATA)
    cargs = []
    cargs.append("3dAFNItoNIFTI")
    cargs.append(execution.input_file(input_dataset))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose:
        cargs.append("-verb")
    if force_float:
        cargs.append("-float")
    if pure:
        cargs.append("-pure")
    if denote:
        cargs.append("-denote")
    if oldid:
        cargs.append("-oldid")
    if newid:
        cargs.append("-newid")
    ret = V3dAfnitoNiftiOutputs(
        root=execution.output_file("."),
        output_nifti=execution.output_file(prefix + ".nii") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAfnitoNiftiOutputs",
    "V_3D_AFNITO_NIFTI_METADATA",
    "v_3d_afnito_nifti",
]
